/* mk_outvec.c
** setup header for outvec_STDOUT.c
** use sysconf() for pulling IOV_MAX on platform
** wcm, 2010.12.01 - 2013.01.07
** ===
*/

#include <stdio.h>
#include <unistd.h>

#define _VEC_STDOUT_MIN  16
#define _VEC_STDOUT_MAX  256

const char  progname[] = "mk_outvec";

int
main(int argc, char * argv[])
{
  long  limit = 0;

  (void)argc;
  (void)argv;

  printf("/* outvec_STDOUT.h\n"
         "** automatically generated by %s (%s) \n"
         "*/\n\n", progname, __FILE__ );

#ifdef _SC_IOV_MAX
  /* try sysconf() to check IOV_MAX limit: */
  limit = sysconf(_SC_IOV_MAX);
#endif
#ifdef IOV_MAX
  /* try IOV_MAX if sysconf() not successful/available: */
  if(limit <= 0)
      limit = IOV_MAX;
#endif

  /* constrain limit to our range: */
  if(limit < _VEC_STDOUT_MIN){
      /* force limit upto posix-asserted minimum: */
      limit = _VEC_STDOUT_MIN;
  }
  if(limit > _VEC_STDOUT_MAX){
      /* constrain excess limit to our upper limit: */
      limit = _VEC_STDOUT_MAX;
  }

  printf("#define _VEC_STDOUT_SIZE  %ld\n\n", limit);
  printf("/* eof: outvec_STDOUT.h */\n");

  return 0;
} 

/* eof: mk_outvec.c */
